rm(list=ls())
library(foreign)
library(BRugs)
library(arm)
library(R2WinBUGS)
library(rjags)
library(runjags)

dat<-read.dta(file="gay_attitudes.dta")
dat$state<-ifelse(dat$state=="", NA, dat$state)
dat<-subset(dat, year==2008)
dat<-na.omit(dat)
dat$churchattend<-as.numeric(dat$church)
dat$partyid<-as.numeric(dat$partyid)

attach(dat)

table(year)

N<-dim(dat)[1]

state.ind<-c()
for(i in 1:length(state)){
  state.ind[i]<-which(unique(state)==state[i])
}

K<-length(unique(state.ind))

state.name<-c()
for(i in 1:K){
  state.name[i]<-unique(state[which(state.ind==i)])
}

# create mean state variable
avg.churchattend<-c()
for(i in 1:K){
  avg.churchattend[i]<-mean(churchattend[which(state.ind==i)])
}


# group mean centering
age.means <- aggregate(dat$age, by=list(state.ind), FUN=mean)[,2]
age.center <- dat$age - age.means[state.ind]
partyid.means <- aggregate(dat$partyid, by=list(state.ind), FUN=mean)[,2]
partyid.center <- dat$partyid - partyid.means[state.ind]
churchattend.means <- aggregate(dat$churchattend, by=list(state.ind), FUN=mean)[,2]
churchattend.center <- dat$churchattend - churchattend.means[state.ind]

set.seed(123456)
jags.dat<- list("N"=N, "K"=K, "gaytherm"=dat$gaytherm, "age"=age.center, "state.ind"=state.ind, "churchattend"=churchattend.center, "partyid"=partyid.center, "avg.churchattend"=avg.churchattend)
jags.inits <- function() {list (b.age = 0, b.church = 0, tau.y=1)}
parameters<- c("gaytherm.ppd")
reg.jags<-jags.model(file="gay_attitudes_ppd.bug", data=jags.dat, inits=jags.inits, n.chains=10, n.adapt=1000)
update(reg.jags, n.iter=2000) # burn in
regression.sim<-coda.samples(reg.jags, variable.names=parameters, n.iter=2000)

plot(density(dat$gaytherm), ylim=c(0, 0.05))
gaytherm.avg.pred <- unlist(colMeans(regression.sim[[1]]))
lines(density(gaytherm.avg.pred), col="red")

plot(density(dat$gaytherm, from=0, to=100), ylim=c(0, 0.05))
lines(density(regression.sim[[1]][1000,], from=0, to=100), col="red")
lines(density(regression.sim[[1]][1200,], from=0, to=100), col="blue")
lines(density(regression.sim[[1]][1400,], from=0, to=100), col="green")
lines(density(regression.sim[[1]][1800,], from=0, to=100), col="orange")

plot(dat$gaytherm ~ gaytherm.avg.pred)
abline(lm(dat$gaytherm ~ gaytherm.avg.pred), col="red")
summary(lm(dat$gaytherm ~ gaytherm.avg.pred))

u <- dat$gaytherm - gaytherm.avg.pred
plot(u ~ dat$gaytherm)
plot(u ~ gaytherm.avg.pred)


detach(dat)