rm(list=ls())
library(foreign)
library(BRugs)
library(arm)
library(R2WinBUGS)
library(rjags)
library(runjags)

dat<-read.dta(file="gay_attitudes.dta")
dat$state<-ifelse(dat$state=="", NA, dat$state)
dat<-subset(dat, year==2008)
dat<-na.omit(dat)
dat$churchattend<-as.numeric(dat$church)
dat$partyid<-as.numeric(dat$partyid)

attach(dat)

table(year)

N<-dim(dat)[1]

state.ind<-c()
for(i in 1:length(state)){
  state.ind[i]<-which(unique(state)==state[i])
}

K<-length(unique(state.ind))

state.name<-c()
for(i in 1:K){
  state.name[i]<-unique(state[which(state.ind==i)])
}

# create mean state variable
avg.churchattend<-c()
for(i in 1:K){
  avg.churchattend[i]<-mean(churchattend[which(state.ind==i)])
}

# group mean centering
age.means <- aggregate(dat$age, by=list(state.ind), FUN=mean)[,2]
age.center <- dat$age - age.means[state.ind]
partyid.means <- aggregate(dat$partyid, by=list(state.ind), FUN=mean)[,2]
partyid.center <- dat$partyid - partyid.means[state.ind]
churchattend.means <- aggregate(dat$churchattend, by=list(state.ind), FUN=mean)[,2]
churchattend.center <- dat$churchattend - churchattend.means[state.ind]

female <- as.numeric(dat$gender)-2
black <- as.numeric(as.numeric(dat$race)==2)



set.seed(123456)
jags.dat<- list("N"=N, "K"=K, "gaytherm"=dat$gaytherm, "age"=age.center, "state.ind"=state.ind, "churchattend"=churchattend.center, "partyid"=partyid.center, "female" = female, "black" = black)
jags.inits <- function() {list (b.age = 0, b.church = 0, b.party=0, b.female=0, b.black=0, tau.y=1)}
parameters<- c("b.state", "b.age", "b.church", "b.party", "b.female", "b.black", "tau.y", "m")
reg.jags<-jags.model(file="gay_attitudes_svs.bug", data=jags.dat, inits=jags.inits, n.chains=10, n.adapt=1000)
update(reg.jags, n.iter=2000) # burn in
regression.sim<-coda.samples(reg.jags, variable.names=parameters, n.iter=2000)

#geweke.diag(regression.sim)
mcmcplot(regression.sim)

summary(regression.sim)

library(mcmcplots)

caterplot(regression.sim[,1:5])

caterplot(regression.sim[,4:37], labels=state.name, reorder=F)
o <- order(apply(X=as.matrix(regression.sim)[,4:37], FUN=median, MARGIN=2), decreasing=T)
caterplot(regression.sim[,3+o], labels=state.name[o], reorder=F)

caterplot(regression.sim[,38:71], labels=state.name, reorder=F)
o <- order(apply(X=as.matrix(regression.sim)[,38:71], FUN=median, MARGIN=2), decreasing=T)
caterplot(regression.sim[,37+o], labels=state.name[o], reorder=F)


















set.seed(123456)
jags.dat<- list("N"=N, "K"=K, "gaytherm"=dat$gaytherm, "age"=age.center, "state.ind"=state.ind, "churchattend"=churchattend.center, "partyid"=partyid.center, "female" = female, "black" = black)
jags.inits <- function() {list (b.age = 0, b.church = 0, b.party=0, b.female=0, b.black=0, tau.y=1, tau.las=1)}
parameters<- c("b.state", "b.age", "b.church", "b.party", "b.female", "b.black", "tau.y", "tau.las")
reg.jags<-jags.model(file="gay_attitudes_lasso.bug", data=jags.dat, inits=jags.inits, n.chains=10, n.adapt=1000)
update(reg.jags, n.iter=2000) # burn in
regression.sim<-coda.samples(reg.jags, variable.names=parameters, n.iter=2000)

mcmcplot(regression.sim)
