# example from: http://twiecki.github.io/blog/2017/02/08/bayesian-hierchical-non-centered/
# and http://twiecki.github.io/blog/2014/03/17/bayesian-glms-3/

rm(list=ls())

dat <- read.csv("radon.csv")
dat <- subset(dat, floor < 8)
dat.full <- dat

dat <- subset(dat, state=="MN")
dat$county.idx <- as.numeric(dat$county)

dat$county.idx <- match(dat$county.idx, unique(dat$county.idx))


head(dat)

library(arm)
library(rjags)
library(coda)
library(mcmcplots)
library(runjags)

N<-dim(dat)[1]
K<- max(unique(dat$county.idx))

jags.dat<- list("N" = N, "K" = K, "radon" = dat$radon, "floor" = dat$floor, "county.idx" = dat$county.idx)
jags.inits <- function() {list (a = 1, mu.b = 0, tau.eta = 1, tau.b = 1, tau.y=1)}
parameters<- c("a", "mu.b", "tau.eta", "tau.b", "sigma.eta", "sigma.b", "b[75]")

set.seed(123456)
reg.jags<-jags.model(file="radon.bug", data=jags.dat, inits=jags.inits, n.chains=3, n.adapt=1000)
update(reg.jags, n.iter=1000) # burn in
regression.sim<-coda.samples(reg.jags, variable.names=parameters, n.iter=20000)

mcmcplot(regression.sim)
#summary(regression.sim)

gelman.diag(regression.sim)
heidel.diag(regression.sim)
geweke.diag(regression.sim)

allchains <- as.matrix(combine.mcmc(regression.sim))

plot(allchains[,"sigma.b"] ~ allchains[,"b[75]"])

plot(density(allchains[,"sigma.b"], from=0, to=0.6))
hist(allchains[,"sigma.b"])

plot(allchains[,"tau.b"] ~ allchains[,"b[75]"])






jags.dat<- list("N" = N, "K" = K, "radon" = dat$radon, "floor" = dat$floor, "county.idx" = dat$county.idx)
jags.inits <- function() {list (tau.eta = 1, tau.b=1, mu.eta = 1, sigma.y = 1, a=0.5)}
parameters<- c("a.adj", "b.adj", "tau.eta", "tau.b", "sigma.eta", "sigma.b", "b.eta.adj[75]", "b.eta[75]")

set.seed(123456)
reg.2.jags<-jags.model(file="radon2.bug", data=jags.dat, inits=jags.inits, n.chains=3, n.adapt=1000)
update(reg.2.jags, n.iter=3000) # burn in
regression.2.sim<-coda.samples(reg.2.jags, variable.names=parameters, n.iter=20000)

mcmcplot(regression.2.sim)
#summary(regression.2.sim)

gelman.diag(regression.2.sim)

allchains.2 <- as.matrix(combine.mcmc(regression.2.sim))
plot(allchains.2[,"sigma.b"] ~ allchains.2[,"b.eta.adj[75]"])

plot(density(allchains[,"sigma.b"], from=0, to=0.6), ylim=c(0,7))
lines(density(allchains.2[,"sigma.b"], from=0, to=0.6), col="red")

plot(allchains.2[,"tau.b"] ~ allchains.2[,"b.eta.adj[75]"])







eta.offset.init <- rnorm(K, 0, 1)
b.offset.init <- rnorm(K, 0, 1)
eta.init <- rnorm(K, 0, 1)
b.init <- rnorm(K, 0, 1)


jags.dat<- list("N" = N, "K" = K, "radon" = dat$radon, "floor" = dat$floor, "county.idx" = dat$county.idx)
jags.inits <- function() {list (mu.eta = 1, mu.b = 0, tau.eta = 1, tau.b = 1, eps=1, eta.offset = eta.offset.init, b.offset = b.offset.init)}
parameters<- c("mu.eta", "sigma.eta", "mu.b", "sigma.b", "b[75]")

set.seed(123456)
reg.3.jags<-jags.model(file="radon3.bug", data=jags.dat, inits=jags.inits, n.chains=3, n.adapt=1000)
update(reg.3.jags, n.iter=3000) # burn in
regression.3.sim<-coda.samples(reg.3.jags, variable.names=parameters, n.iter=20000)

mcmcplot(regression.3.sim)
#summary(regression.3.sim)

gelman.diag(regression.3.sim)

allchains.3 <- as.matrix(combine.mcmc(regression.3.sim))

plot(density(allchains[,"sigma.b"], from=0, to=0.6), ylim=c(0,7))
lines(density(allchains.2[,"sigma.b"], from=0, to=0.6), col="red")
lines(density(allchains.3[,"sigma.b"], from=0, to=0.6), col="blue")


